==> dde-network-core_1.0.64.orig.tar.xz: dde-network-core-1.0.64/dss-network-plugin/translations/dss-network-plugin_de.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="de" version="2.1">
<context>
    <name>Bubble</name>
    <message>
        <source>1 new message</source>
        <translation>1 neue Nachricht</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Connecting %1</source>
        <translation>%1 wird verbunden</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 verbunden</translation>
    </message>
    <message>
        <source>%1 disconnected</source>
        <translation>%1 getrennt</translation>
    </message>
    <message>
        <source>Unable to connect %1, please check your router or net cable.</source>
        <translation>Verbindung zu %1 nicht möglich, bitte überprüfen Sie Ihren Router oder Ihr Netzkabel.</translation>
    </message>
    <message>
        <source>Unable to connect %1, please keep closer to the wireless router</source>
        <translation>Verbindung zu %1 nicht möglich, bitte näher am WLAN-Router bleiben</translation>
    </message>
    <message>
        <source>Connection failed, unable to connect %1, wrong password</source>
        <translation>Verbindung fehlgeschlagen, Verbindung zu %1 nicht möglich, falsches Passwort</translation>
    </message>
    <message>
        <source>Password is required to connect %1</source>
        <translation>Für die Verbindung mit %1 ist ein Passwort erforderlich</translation>
    </message>
    <message>
        <source>The %1 802.11 WLAN network could not be found</source>
        <translation>Das %1 802.11-WLAN-Netzwerk konnte nicht gefunden werden</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Wired Connection</source>
        <translation>Kabelgebundene Verbindung</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protokoll</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Sicherheitstyp</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Band</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Kanal</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Schnittstelle</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Netzmaske</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Primärer DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Präfix</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Geschwindigkeit</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Gerät deaktiviert</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Verbunden, aber kein Internetzugang</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Nicht verbunden</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Netzwerkkabel abgezogen</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Wird verbunden</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Wird authentifiziert</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>IP-Adresse wird abgerufen</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Verbunden</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Getrennt</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP Konflikt</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Fehlgeschlagen</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Adresse wird abgerufen</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Kabelgebundenes Netzwerk</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Kabelgebundenes Netzwerk %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Drahtlosnetzwerk</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Drahtlosnetzwerk %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Gerät deaktiviert</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Netzwerkkabel abgezogen</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Nicht verbunden</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Wird verbunden</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Verbunden, aber kein Internetzugang</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Verbindung fehlgeschlagen</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP Konflikt</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Kabelgebundene Verbindung deaktivieren</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Kabelgebundene Verbindung aktivieren</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Drahtlosverbindung deaktivieren</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Drahtlosverbindung aktivieren</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Netzwerk deaktivieren</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Netzwerk aktivieren</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Netzwerkeinstellungen</translation>
    </message>
</context>
</TS>

==> dde-network-core_1.1.5.orig.tar.xz: dde-network-core-1.1.5/dss-network-plugin/translations/dss-network-plugin_de.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de">
<context>
    <name>Bubble</name>
    <message>
        <source>1 new message</source>
        <translation>1 neue Nachricht</translation>
    </message>
</context>
<context>
    <name>DeviceControllItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>Drahtlosnetzwerk</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Kabelgebundenes Netzwerk</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Connecting %1</source>
        <translation>%1 wird verbunden</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 verbunden</translation>
    </message>
    <message>
        <source>%1 disconnected</source>
        <translation>%1 getrennt</translation>
    </message>
    <message>
        <source>Unable to connect %1, please check your router or net cable.</source>
        <translation>Verbindung zu %1 nicht möglich, bitte überprüfen Sie Ihren Router oder Ihr Netzkabel.</translation>
    </message>
    <message>
        <source>Unable to connect %1, please keep closer to the wireless router</source>
        <translation>Verbindung zu %1 nicht möglich, bitte näher am WLAN-Router bleiben</translation>
    </message>
    <message>
        <source>Connection failed, unable to connect %1, wrong password</source>
        <translation>Verbindung fehlgeschlagen, Verbindung zu %1 nicht möglich, falsches Passwort</translation>
    </message>
    <message>
        <source>Password is required to connect %1</source>
        <translation>Für die Verbindung mit %1 ist ein Passwort erforderlich</translation>
    </message>
    <message>
        <source>The %1 802.11 WLAN network could not be found</source>
        <translation>Das %1 802.11-WLAN-Netzwerk konnte nicht gefunden werden</translation>
    </message>
</context>
<context>
    <name>WirelessItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>Mit verstecktem Netzwerk verbinden</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Passwort</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Connect</source>
        <comment>button</comment>
        <translation>Verbinden</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>Name (SSID)</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protokoll</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Sicherheitstyp</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Kanal</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Band</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Schnittstelle</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Netzmaske</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Primärer DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Präfix</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Geschwindigkeit</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Gerät deaktiviert</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Verbunden, aber kein Internetzugang</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Nicht verbunden</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Netzwerkkabel abgezogen</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Wird verbunden</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Wird authentifiziert</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>IP-Adresse wird abgerufen</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Verbunden</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Getrennt</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP Konflikt</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Fehlgeschlagen</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Adresse wird abgerufen</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Kabelgebundenes Netzwerk</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Kabelgebundenes Netzwerk %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Drahtlosnetzwerk</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Drahtlosnetzwerk %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Gerät deaktiviert</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Netzwerkkabel abgezogen</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Nicht verbunden</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Wird verbunden</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Verbunden, aber kein Internetzugang</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Verbindung fehlgeschlagen</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP Konflikt</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Kabelgebundene Verbindung deaktivieren</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Kabelgebundene Verbindung aktivieren</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Drahtlosverbindung deaktivieren</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Drahtlosverbindung aktivieren</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Netzwerk deaktivieren</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Netzwerk aktivieren</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Netzwerkeinstellungen</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Wired Connection</source>
        <translation>Kabelgebundene Verbindung</translation>
    </message>
</context>
</TS>
